<%@ Control Language="vb" debug="true"%>

<script runat="server">

Public jsDir as String ="../../ricoClient/js/"       ' directory containing Rico's javascript files
Public cssDir as String ="../../ricoClient/css/"     ' directory containing Rico's css files
Public imgDir as String ="../../ricoClient/images/"  ' directory containing Rico's image files
Public transDir as String =jsDir & "translations/"
Public baselibsDir as String =jsDir & "baselibs/"

Public jslib as String = "proto"           ' base library (proto, jquery, moo, dojo, ext, or glow)
Public modules as String                   ' comma separated list of Rico modules to load
Public ricoLogging as Boolean = false      ' enable javascript console logging?
Public language as String                  ' if left unset, language will be set automatically based on request's HTTP_ACCEPT_LANGUAGE
Public checkQueryString as Boolean = true  ' load settings from QueryString?  true for demo, false for production
Public LoadBaseLib as Boolean = true       ' load base Javascript library (prototype, jQuery, etc) from Rico directory?
Public grid_striping as Boolean = true     ' apply row striping to LiveGrids?
Public jQuery_theme_path as String = "http://ajax.googleapis.com/ajax/libs/jqueryui/1.7.2/themes/"

Protected theme as String = "j-ui-lightness"  ' jquery themes start with j-, rico themes start with r-


Protected Overrides Sub Render(writer as HTMLTextWriter)
  if checkQueryString then ricoLogging=CBool(trim(Request.QueryString("log")) <> "")
  SetConfig(writer)

  dim qs as String
  if checkQueryString then
    qs=trim(Request.QueryString("lib"))
    if qs<>"" then jslib=qs
  end if
  LoadLib(writer, LCase(jslib))

  if IsNothing(language) then language=Request.ServerVariables("HTTP_ACCEPT_LANGUAGE")
  setLang(writer, language)

  if checkQueryString then
    qs=trim(Request.QueryString("theme"))
    if qs<>"" then theme=qs
  end if
  if theme<>"" then
    LoadTheme(writer, theme)
  end if
  if modules<>"" then
    dim ricoModule as String
    dim arModules=split(modules,",")
    for each ricoModule in arModules
      requireRicoModule(writer, ricoModule)
    next
  end if
end sub


' -------------------------------------------------------------
' do client-side initialization
' -------------------------------------------------------------
Protected sub SetConfig(writer as HTMLTextWriter)
  writer.Write(vbLf & "<script type='text/javascript'>")
  writer.Write(vbLf & "Rico_CONFIG = {")
  if ricoLogging then writer.Write(vbLf & "enableLogging: true,")
  writer.Write(vbLf & "jsDir: '" & jsDir & "',")
  writer.Write(vbLf & "cssDir: '" & cssDir & "',")
  writer.Write(vbLf & "imgDir: '" & imgDir & "'")
  writer.Write(vbLf & "};")
  writer.Write(vbLf & "</" & "script>")
end sub


' -------------------------------------------------------------
' set theme to one of the jQuery Themeroller themes
' -------------------------------------------------------------
Public WriteOnly Property jTheme() As String
  Set(ByVal ThemeName As String)
    theme="j_" & ThemeName
  End Set
End Property


' -------------------------------------------------------------
' set theme to one of the Rico themes
' -------------------------------------------------------------
Public WriteOnly Property ricoTheme() As String
  Set(ByVal ThemeName As String)
    theme="r_" & ThemeName
  End Set
End Property


' -------------------------------------------------------------
' Check specifed languages and see if there is a ricoLocale file to match
' -------------------------------------------------------------
Protected sub setLang(writer as HTMLTextWriter, lang as String)
  dim lang2,fname,i
  
  dim arLang=split(LCase(lang),",")
  for i=0 to ubound(arLang)
    lang2=lcase(left(trim(arLang(i)),2))
    if lang2="en" then exit for
    fname=transDir & "ricoLocale_" & lang2 & ".js"
    if System.IO.File.Exists(Server.MapPath(fname)) then
      writer.Write("<script src='" & fname & "' type='text/javascript'></" & "script>")
      exit for
    end if
  next
end sub


Protected sub LoadLib(writer as HTMLTextWriter, baseLib as String)
  dim baseFile,adapter
  select case baseLib
    case "proto":
      baseFile="prototype"
      adapter="2Proto"
    case "jquery":
      baseFile="jquery"
      adapter="2jQuery"
    case "moo":
      baseFile="mootools"
      adapter="2Moo"
    case "dojo":
      baseFile="dojo"
      adapter="2Dojo"
    case "ext":
      baseFile="ext-core"
      adapter="2Ext"
    case "glow":
      baseFile="glow.core"
      adapter="2Glow"
    case else:
      Response.End
  end select

  if LoadBaseLib then writer.Write(vbLf & "<script src='" & baselibsDir & baseFile & ".js' type='text/javascript'></" & "script>")
  requireRicoJS(writer, "")
  requireRicoJS(writer, adapter)
  writer.Write(vbLf & "<script src='" & transDir & "ricoLocale_en.js' type='text/javascript'></" & "script>")
  requireRicoCSS(writer, "rico")
  requireRicoJS(writer, "UI")
end sub



' -------------------------------------------------------------
' set theme
' "j-ui-lightness" for a Themeroller theme
' "r-greenHdg" for a native Rico theme
' -------------------------------------------------------------
Protected sub LoadTheme(writer as HTMLTextWriter, theme as String)
  dim prefix,themeFile
  prefix=left(theme,1)
  themeFile=mid(theme,3)
  select case prefix
    case "j":
      requireRicoJS(writer, "Themeroller")
      writer.Write(vbLf & "<link type='text/css' rel='stylesheet' href='" & cssDir & "jquery-base/ui.base.css' />")
      writer.Write(vbLf & "<link type='text/css' rel='Stylesheet' href='" & jQuery_theme_path & themeFile & "/jquery-ui.css' />")
    case "r":
      requireRicoCSS(writer, themeFile)
  end select
  if grid_striping then writer.Write(vbLf & "<link type='text/css' rel='stylesheet' href='" & cssDir & "striping/" & themeFile & ".css' />")
end sub


Protected sub requireRicoModule(writer as HTMLTextWriter, modulename as String)
  writer.Write(vbLf & "<script type='text/javascript'>Rico.loadModule('" & trim(modulename) & "');</" & "script>")
end sub


Protected sub requireRicoJS(writer as HTMLTextWriter, filename as String)
  writer.Write(vbLf & "<script src='" & jsDir & "rico" & filename & ".js' type='text/javascript'></" & "script>")
end sub


Protected sub requireRicoCSS(writer as HTMLTextWriter, filename as String)
  writer.Write(vbLf & "<link href='" & cssDir & filename & ".css' type='text/css' rel='stylesheet' />")
end sub

</script>
